#
# spec file for package xrdb
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xrdb
Version:        1.2.2
Release:        1.1
Summary:        X server resource database utility
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xmuu)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
Recommends:     cpp
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
Xrdb is used to get or set the contents of the RESOURCE_MANAGER property
on the root window of screen 0, or the SCREEN_RESOURCES property on the
root window of any or all screens, or everything combined.

%prep
%setup -q

%build
# Run cpp with "-x assembler-with-cpp" in order to get rid of
# warnings when parsing valid comments (bsc#1120004)
%configure --with-cpp="%{_bindir}/cpp -x assembler-with-cpp"
%make_build

%install
%make_install

%files
%license COPYING
%doc AUTHORS ChangeLog README.md
%{_bindir}/xrdb
%{_mandir}/man1/xrdb.1%{?ext_man}

%changelog
* Sat Jun 10 2023 Stefan Dirsch <sndirsch@suse.com>
- Updat to version 1.2.2
  * gitlab CI: add a basic build test
  * gitlab CI: stop requiring Signed-off-by in commits
  * Variable scope reduction as recommended by cppcheck
  * Use C99 struct initialization
  * Rename variable 'dup' to avoid shadowing dup() function
  * Fallback asprintf: don't truncate output that has a \0 in string
  * configure: raise minimum autoconf requirement to 2.70
* Thu May 11 2023 Michal Suchanek <msuchanek@suse.com>
- Downgrade cpp requires to recommends (bsc#1211267)
* Wed Sep 29 2021 Ludwig Nussel <lnussel@suse.de>
- Remove fallback to /lib/cpp, it's the same package as /usr/bin/cpp
  anyway (boo#1191060).
* Sat Aug 28 2021 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.1
  * bugfix release
* Sat May  1 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file (move license to licensedir)
* Thu Feb 21 2019 sndirsch@suse.com
- Update to version 1.2.0
  * This release adds a -E flag to see the preprocessor command
    issued and the output of the preprocessor, to aid in debugging.
* Thu Jan 10 2019 sndirsch@suse.com
- run cpp with "-x assembler-with-cpp" in order to get rid of
  warnings when parsing valid comments (bsc#1120004)
* Wed Apr  4 2018 sndirsch@suse.com
- Update to version 1.1.1
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: Honor NOCONFIGURE=1
  * configure: add more m4 quoting to quiet autoconf complaints
  * Remove unused macro RESOURCE_PROPERTY_NAME
  * Clean up sign/size conversion warnings from clang
  * Stop casting free() arguments to (char *)
  * unifdef -U__UNIXOS2__
  * Print which option was in error along with usage message
  * Use SEEK_* names instead of raw numbers for fseek whence argument
  * Reformat code to X.Org standard coding style
  * Fix "editting" typo in comment
  * Use reallocarray() for array allocations & resizing
  * autogen.sh: use quoted string variables
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish
* Thu Sep 12 2013 zaitor@opensuse.org
- Update to version 1.1.0:
  + Add -version flag to print package version string from
    autoconf.
  + Only add -P flag if using cpp as our preprocessor (fdo#34546).
  + Predefined cpp macros can produce unexpected results
    (fdo#3413).
  + Rename args to several functions to not shadow global
    variables.
  + Mark fatal() & Syntax() with printf & noreturn attributes.
  + Strip trailing whitespace.
  + Remove unnecessary casts from malloc & realloc calls.
  + Fix many const pointer warnings.
  + Ensure we don't read out of ClassName array bounds for unknown
    visual type (deb#488535).
  + Clarify .Xresources vs. .Xdefaults in man page (deb#649187).
  + Allow the CPP macro to contain preprocessors with command line
    options (v2).
  + Usage: In usage message print preprocessor that's actually
    chosen.
  + Fix build with WIN32 defined, but PATHETICCPP not defined.
  + Tokenize #define names in the PATHETICCPP case too.
- Add pkgconfig(xproto) BuildRequires, new dependency.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.0.9:
  + Create shell-escape-safe cpp options in the non-pathetic-cpp
    case (CVE-2011-0465).
- Changes from version 1.0.8:
  + Merge usage() printf() strings/calls into a single string/call.
  + Replace complex malloc calculations with asprintf().
  + Man page fixes.
  + Build system fixes.
- Drop xrdb-Create-shell-escape-safe-cpp-options-in-the-non-path-bnc674733.patch:
  fixed upstream.
- Drop xrdb-traditional-cpp.diff: obsoleted.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xrdb from xorg-x11. Initial version: 1.0.7.
